@@ -20,21 +20,23 @@
 #ifndef __STICKYNOTES_H__
 #define __STICKYNOTES_H__
 
+#define WNCK_I_KNOW_THIS_IS_UNSTABLE 1
+#include <libwnck/libwnck.h>
 #include <stickynotes_applet.h>
 
 typedef struct
 {
-	GladeXML *window;		/* Glade object for note window */
-	GladeXML *menu;			/* Glade object for note popup menu */
-	GladeXML *properties;		/* Glade object for note properties dialog */
-
 	GtkWidget *w_window;		/* Sticky Note window */
 	GtkWidget *w_menu;		/* Sticky Note menu */
 	GtkWidget *w_properties;	/* Sticky Note properties dialog */
 
 	GtkWidget *w_entry;		/* Sticky Note title entry */
 	GtkWidget *w_color;		/* Sticky Note color picker */
+	GtkWidget *w_color_label;	/* Sticky Note color label */
+	GtkWidget *w_font_color;	/* Sticky Note font color picker */
+	GtkWidget *w_font_color_label;	/* Sticky Note font color label */
 	GtkWidget *w_font;		/* Sticky Note font picker */
+	GtkWidget *w_font_label;	/* Sticky Note font label */
 	GtkWidget *w_def_color;		/* Sticky Note default color setting */
 	GtkWidget *w_def_font;		/* Sticky Note default font setting */
 
@@ -45,16 +47,25 @@ typedef struct
 	GtkWidget *w_resize_se;		/* Sticky Note resize button (south east) */
 	GtkWidget *w_resize_sw;		/* Sticky Note resize button (south west) */
 
+	GtkWidget *w_lock_toggle_item;	/* Lock item in the popup menu */
+
+	GtkImage *img_lock;		/* Lock image */
+	GtkImage *img_close;		/* Close image */
+	GtkImage *img_resize_se;	/* SE resize image */
+	GtkImage *img_resize_sw;	/* SW resize image */
+
 	gchar *color;			/* Note color */
+	gchar *font_color;		/* Font color */
 	gchar *font;			/* Note font */
 	gboolean locked;		/* Note locked state */
-	gboolean visible;		/* Note visibility */
 	
 	gint x;				/* Note x-coordinate */
 	gint y;				/* Note y-coordinate */
 	gint w;				/* Note width */
 	gint h;				/* Note height */
 
+	int workspace;			/* Workspace the note is on */
+
 } StickyNote;
 
 StickyNote * stickynote_new(GdkScreen *screen);
@@ -63,7 +74,10 @@ void stickynote_free(StickyNote *note);
 gboolean stickynote_get_empty(const StickyNote *note);
 
 void stickynote_set_title(StickyNote *note, const gchar* title);
-void stickynote_set_color(StickyNote *note, const gchar* color_str, gboolean save);
+void stickynote_set_color (StickyNote  *note,
+		           const gchar *color_str,
+			   const gchar *font_color_str,
+			   gboolean     save);
 void stickynote_set_font(StickyNote *note, const gchar* font_str, gboolean save);
 void stickynote_set_locked(StickyNote *note, gboolean locked);
 void stickynote_set_visible(StickyNote *note, gboolean visible);
